# 欢迎下载BeautyPrinting！
## 你是否想要拥有幻彩的打印输出？
```python
import BeautyPrinting

BeautyPrinting.BtPrint.btprint('Colorful Hello World!', color='cyan')
```
###### 两行代码，就可以拥有炫彩的“Hello World”
## 你是否想要拥有炫酷的加载进度条？
```python
import BeautyPrinting

BeautyPritning.ProgressBar.loading_bar('Loading......', items=50, color='cyan')
```
###### 两行代码，轻松拥有多彩的加载条
## 赶紧下载我们BeautyPrinting吧！一定能满足您的美学需求！